<p align="center">
  <img src="https://github.com/gibiee/img64/assets/37574274/1e4ba6f4-776d-4e84-b589-09f75d64d175" width="50%" height="50%" />
</p>

This library is a tool for converting images to base64 encoding and vice versa.

- It was implemented by referencing [ternaus/base64ToImageConverters](https://github.com/ternaus/base64ToImageConverters).
  - The referenced code didn't ensure data consistency, so this code improves that issue.
  - This code enhances user convenience in handling both RGB and grayscale images.
